#
# spec file for package qore-xml-module
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qore_version 1.0.10
%define module_api   %(qore --latest-module-api 2>/dev/null)
%define src_name     module-xml-release-%{qore_version}
Name:           qore-xml-module
Version:        1.5.1+qore%{qore_version}
Release:        bp154.1.33
Summary:        XML module for Qore
License:        LGPL-2.1-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Languages/Other
URL:            https://qore.org
Source:         https://github.com/qorelanguage/module-xml/archive/refs/tags/release-%{qore_version}.tar.gz#/%{src_name}.tar.gz
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  qore
BuildRequires:  qore-devel >= %{qore_version}
Requires:       qore-module(abi)%{?_isa} = %{module_api}

%description
This package contains the xml module for the Qore Programming Language.

XML is a markup language for encoding information.

%package doc
Summary:        Documentation and examples for the Qore xml module
Group:          Development/Languages

%description doc
This package contains the HTML documentation and example programs for the Qore
xml module.

%package tools
Summary:        User tools writen in Qore Programming Language
License:        GPL-2.0-or-later OR LGPL-2.0-or-later OR MIT
Group:          Development/Tools/Other
Requires:       %{name} = %{version}-%{release}

%description tools
This package contains the webdav server and soap utils.

%prep
%setup -q -n %{src_name}

%build
%cmake
%make_build docs

%install
%cmake_install
%fdupes -s %{__builddir}/html
# Fix scripts
find examples -name "*.q" -exec sed -i '1 s/env qore/qore/' \{\} +
for f in "%{buildroot}%{_bindir}/"{soaputil,webdav-server}; do sed -i '1 s/env qore/qore/' "$f"; done

%files
%license COPYING.LGPL COPYING.MIT
%{_datadir}/qore-modules
%{_libdir}/qore-modules

%files doc
%doc %{__builddir}/html examples

%files tools
%doc README RELEASE-NOTES
%{_bindir}/webdav-server
%{_bindir}/soaputil

%changelog
* Sun Oct 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.1 for Qore 1.0.10
  * Added initial WebDAV module support in the xml module
  * Fixed errors handling missing message descriptions
  * Fixed a bug serializing xml comments
  * Fixed a type error handling messages in listeners without a
    hostname key in the socket info hash of the connection context hash
* Sat Jun 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.0 for qore 0.9.5
  * Added support for new ConnectionProvider APIs
  * Added support for the FileLocationHandler module when
    retrieving WSDLs
  * Added support for connection serialization
  * Added data provider API support
  * Added feature: Object serialization
  * Use new HTTPClient APIs to ensure that socket events are
    raised correctly
  * Fixed SOAP response msg to currespond to the type
  * Fixed a bug where serialization errors were not thrown with
    unserializable data types
  * Fixed a bug parsing empty string values with xmlns attributes
  * Fixed WSDL serialization
* Sat Dec 19 2020 sarah.kriesch@opensuse.org
- enable s390x architecture in spec file
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.1:
  * huge list of changes, see https://docs.qore.org/modules/xml/1.4.1/xml/html/#xml141
* Mon Aug 31 2015 normand@linux.vnet.ibm.com
- add --enable-64bit as already done for other qore-*-module
* Mon Jul 28 2014 petr@yarpen.cz
- migrated to OBS file layout
